@@ -226,9 +226,11 @@ class IrcBot(object):
                 'USER '+" ".join([self.username]*3)+' :' + self.nick + ' \r\n').encode()
             await s.send_all(usernam_cr)
 
-            await self.ping_confirmation(s)
-
-            await trio.sleep(2)
+            ping_confirmed = False
+            with trio.fail_after(4):
+                await self.ping_confirmation(s)
+                ping_confirmed=True
+                await trio.sleep(2)
 
             if self.password:
                 log("IDENTIFYING")
@@ -237,6 +239,7 @@ class IrcBot(object):
                 await s.send_all(auth_cr)
 
 
+            await trio.sleep(2)
             if self.use_sasl:
                 import base64
                 await s.send_all(("AUTHENTICATE PLAIN").encode())
@@ -490,4 +493,3 @@ class IrcBot(object):
         """Stops the bot and loop if running."""
         self.__del__()
 
-
